@@ -29,9 +29,11 @@
 # 05-SEP-2019   B. Ulmann   Added set_ro_group and read_ro_group functions.
 # 11-SEP-2019   B. Ulmann   Made HyCon into a proper Perl module suitable 
 #                           for CPAN.
+# 12-SEP-2019   B. Ulmann   Added requirements to Makefile.PL which were 
+#                           missing.
 #
 
-package HyCon;
+package IO::HyCon;
 
 =pod
 
@@ -75,7 +77,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-our $VERSION = '0.1';
+our $VERSION = '0.1_2';
 
 use YAML qw(LoadFile);
 use Carp qw(confess cluck carp);
